from .exeptions import TaxInvalidError

class Taxes:
    def __init__(self,percentage):
        if not (0<=percentage<+1):
            raise TaxInvalidError ("Taxes rates have to be between 0 and 1, type again")
        
        self.percentage=percentage
        
    def tax_application (self,price):
        return price*self.percentage


from .exeptions import DiscountInvalidError

class Discounts:
    def __init__(self,percentage):
        if not (0<=percentage<=1):
            raise DiscountInvalidError('Discount pecentage has to be between 0 and 1, type again')
        
        self.percentage=percentage
        
    def discount_application(self,price):
        return price*self.percentage
    
    


import unittest
from sells_application.sells_control import Sells_Control
from sells_application.exeptions import TaxInvalidError,DiscountInvalidError

class TestControlSells(unittest.TestCase):
    
    def test_final_price(self):
        gestor=Sells_Control(100.0,0.05,0.10)
        self.assertEqual(gestor.final_price_calculation(),95)
        
    def test_tax_invalid(self):
        with self.assertRaises(TaxInvalidError):
            Sells_Control(100.0,1.5,0.10)
            
    def test_dicount_invalid(self):
        with self.assertRaises(DiscountInvalidError):
            Sells_Control(100.0,0.05,1.50)
            
if __name__=="__main__":
    unittest.main()


from .discounts import Discounts
from .taxes import Taxes
from .prices import Prices

class Sells_Control:
    def __init__(self,price_base,tax_percentage,discount_percentage):
        self.price_base=price_base
        self.tax=Taxes(tax_percentage)
        self.discount=Discounts(discount_percentage)
        
    def final_price_calculation(self):
        discount_applied=self.discount.discount_application(self.price_base)
        tax_applied=self.tax.tax_application(self.price_base)
        final_price_applied=Prices.final_price(self.price_base,tax_applied,discount_applied)
        return round(final_price_applied,)


from setuptools import setup,find_packages

setup(
    name='Sells_Application',
    version='0.1.0',
    long_description=open('README.md').read(),
    long_description_content_type= 'text/markdown',
    author='Henry Araya',
    author_email='arayaaraya_1@hotmail.com',
    description='Package for mannaging sells',
    maintainer='Henry Araya',
    url='http://github.com/sells_application',
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.7'
      
    )

#http://pypi.org/account/register/

